@@ -1,5 +1,6 @@
 import unittest
 
+from . import CacheTestMixin
 from cachetools import LRUCache, lru_cache
 
 
@@ -13,54 +14,57 @@ def cached_typed(n):
     return n
 
 
-class LRUCacheTest(unittest.TestCase):
+class LRUCacheTest(unittest.TestCase, CacheTestMixin):
 
-    def test_insert(self):
-        cache = LRUCache(maxsize=2)
+    def make_cache(self, maxsize, getsizeof=None):
+        return LRUCache(maxsize, getsizeof)
 
-        cache['a'] = 1
-        cache['b'] = 2
-        cache['c'] = 3
+    def test_lru_insert(self):
+        cache = self.make_cache(maxsize=2)
+
+        cache[1] = 1
+        cache[2] = 2
+        cache[3] = 3
 
         self.assertEqual(len(cache), 2)
-        self.assertEqual(cache['b'], 2)
-        self.assertEqual(cache['c'], 3)
-        self.assertNotIn('a', cache)
+        self.assertEqual(cache[2], 2)
+        self.assertEqual(cache[3], 3)
+        self.assertNotIn(1, cache)
 
-        cache['b']
-        cache['d'] = 4
+        cache[2]
+        cache[4] = 4
         self.assertEqual(len(cache), 2)
-        self.assertEqual(cache['b'], 2)
-        self.assertEqual(cache['d'], 4)
-        self.assertNotIn('c', cache)
+        self.assertEqual(cache[2], 2)
+        self.assertEqual(cache[4], 4)
+        self.assertNotIn(3, cache)
 
-        cache['e'] = 5
+        cache[5] = 5
         self.assertEqual(len(cache), 2)
-        self.assertEqual(cache['d'], 4)
-        self.assertEqual(cache['e'], 5)
-        self.assertNotIn('b', cache)
+        self.assertEqual(cache[4], 4)
+        self.assertEqual(cache[5], 5)
+        self.assertNotIn(2, cache)
 
-    def test_getsizeof(self):
-        cache = LRUCache(maxsize=3, getsizeof=lambda x: x)
+    def test_lru_getsizeof(self):
+        cache = self.make_cache(maxsize=3, getsizeof=lambda x: x)
 
-        cache['a'] = 1
-        cache['b'] = 2
+        cache[1] = 1
+        cache[2] = 2
 
         self.assertEqual(len(cache), 2)
-        self.assertEqual(cache['a'], 1)
-        self.assertEqual(cache['b'], 2)
+        self.assertEqual(cache[1], 1)
+        self.assertEqual(cache[2], 2)
 
-        cache['c'] = 3
+        cache[3] = 3
 
         self.assertEqual(len(cache), 1)
-        self.assertEqual(cache['c'], 3)
-        self.assertNotIn('a', cache)
-        self.assertNotIn('b', cache)
+        self.assertEqual(cache[3], 3)
+        self.assertNotIn(1, cache)
+        self.assertNotIn(2, cache)
 
         with self.assertRaises(ValueError):
-            cache['d'] = 4
+            cache[4] = 4
         self.assertEqual(len(cache), 1)
-        self.assertEqual(cache['c'], 3)
+        self.assertEqual(cache[3], 3)
 
     def test_decorator(self):
         self.assertEqual(cached.cache_info(), (0, 0, 2, 0))
